#!/bin/sh
#
#	plasticfs - the plastic file system
#	Copyright (C) 2003 Peter Miller;
#	All rights reserved.
#
#	This program is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
#
# MANIFEST: Test the viewpath functionality
#
here=`pwd`
if test $? -ne 0 ; then exit 2; fi
work=${TMP_DIR-/tmp}/$$

pass()
{
	cd $here
	rm -rf $work
	echo PASSED
	exit 0
}

fail()
{
	cd $here
	rm -rf $work
	echo 'FAILED test of the viewpath functionality'
	exit 1
}

no_result()
{
	cd $here
	rm -rf $work
	echo 'NO RESULT for test of the viewpath functionality'
	exit 2
}

trap "no_result" 1 2 3 15

bin=$here/${1-.}/bin
mkdir $work
if test $? -ne 0; then no_result; fi
cd $work
if test $? -ne 0; then no_result; fi

mkdir -p vp1/a/b vp2/a/b vp3/a/b
if test $? -ne 0; then no_result; fi
date > vp2/a/b/xx
if test $? -ne 0; then no_result; fi
date > vp3/a/b/yy
if test $? -ne 0; then no_result; fi
date > vp2/a/w1
if test $? -ne 0; then no_result; fi
date > vp3/a/w2
if test $? -ne 0; then no_result; fi

cd vp1/a/b
if test $? -ne 0; then no_result; fi

nohidden=
LD_PRELOAD=libc.nohidden.so true > /dev/null 2>&1 && nohidden=libc.nohidden.so

PLASTICFS="viewpath $work/vp1 $work/vp2 $work/vp3" \
LD_PRELOAD="$here/${1-.}/lib/.libs/libplasticfs.so $nohidden" \
PWD=/bogus \
/bin/pwd > $work/test.out 2>&1
if test $? -ne 0; then cat $work/test.out; fail; fi

# diff test.ok test.out
# if test $? -ne 0; then fail; fi

#
# The things tested here, worked.
# No other guarantees are made.
#
pass
