//
//	plasticfs - the plastic file system
//	Copyright (C) 2003 Peter Miller;
//	All rights reserved.
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to impliment the fopen class
//

#include <cstdio>
#include <cstdlib>


int
main(int argc, char **argv)
{
    if (argc != 3)
    {
	fprintf(stderr, "%s <infile> <outfile>\n", argv[0]);
	exit(1);
    }
    const char *ifn = argv[1];
    FILE *ifp = fopen(ifn, "r");
    if (!ifp)
    {
	perror(ifn);
	exit(1);
    }
    const char *ofn = argv[2];
    FILE *ofp = fopen(ofn, "w");
    if (!ofp)
    {
	perror(ofn);
	exit(1);
    }
    for (;;)
    {
	int c = getc(ifp);
	if (c == EOF)
	{
	    if (ferror(ifp))
	    {
		perror(ifn);
		exit(1);
	    }
	    break;
	}
	if (putc(c, ofp) == EOF)
	{
	    perror(ofn);
	    exit(1);
	}
    }
    if (fclose(ifp))
    {
	perror(ifn);
	exit(1);
    }
    if (fclose(ofp))
    {
	perror(ofn);
	exit(1);
    }
    exit(0);
    return 0;
}
